"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getUserConfig = void 0;
var path = require("path");
var fs = require("fs");
var utils_1 = require("./utils");
var logger_1 = require("./utils/logger");
function getUserConfig(configFile, root) {
    if (!configFile) {
        configFile = 'bundler.config.js';
        var extenstions = ['ts', 'js'];
        for (var _i = 0, extenstions_1 = extenstions; _i < extenstions_1.length; _i++) {
            var ext = extenstions_1[_i];
            var fileName = "bundler.config.".concat(ext);
            if (fs.existsSync(path.resolve(root, fileName))) {
                configFile = fileName;
                break;
            }
        }
    }
    var configFilePath = path.resolve(root, configFile);
    if (!fs.existsSync(configFilePath)) {
        logger_1.Logger.error("Config file not found: ".concat(configFilePath));
        process.exit(1);
    }
    var config;
    if (/\.js$/.test(configFilePath)) {
        config = (0, utils_1.compactDefault)(require(configFilePath));
    }
    else if (/\.ts$/.test(configFilePath)) {
        require('ts-node').register({
            transpileOnly: true,
            compilerOptions: {
                module: 'commonjs',
                target: 'es6',
            },
        });
        config = (0, utils_1.compactDefault)(require(configFilePath));
    }
    return (0, utils_1.makeArray)(config);
}
exports.getUserConfig = getUserConfig;
